"""A base site type for validation purposes that can be extended elsewhere."""

from pydantic import BaseModel

from gso.products.product_blocks.site import SiteTier
from gso.utils.types.coordinates import LatitudeCoordinate, LongitudeCoordinate
from gso.utils.types.country_code import CountryCode
from gso.utils.types.ip_address import IPAddress
from gso.utils.types.site_name import SiteName
from gso.utils.types.unique_field import UniqueField


class BaseSiteValidatorModel(BaseModel):
    """A base site validator model extended by create site and by import site."""

    site_bgp_community_id: UniqueField[int]
    site_internal_id: UniqueField[int]
    site_tier: SiteTier
    site_ts_address: UniqueField[IPAddress]
    site_country_code: CountryCode
    site_name: UniqueField[SiteName]
    site_city: str
    site_country: str
    site_latitude: LatitudeCoordinate
    site_longitude: LongitudeCoordinate
    partner: str
