"""Workflow for terminating a Layer 2 Circuit."""

from orchestrator import begin, workflow
from orchestrator.forms import FormPage
from orchestrator.targets import Target
from orchestrator.types import SubscriptionLifecycle, UUIDstr
from orchestrator.workflow import StepList, done
from orchestrator.workflows.steps import resync, set_status, store_process_subscription, unsync
from orchestrator.workflows.utils import wrap_modify_initial_input_form
from pydantic_forms.types import FormGenerator

from gso.products.product_types.layer_2_circuit import Layer2Circuit
from gso.utils.types.tt_number import TTNumber


def _input_form_generator(subscription_id: UUIDstr) -> FormGenerator:
    layer_2_circuit = Layer2Circuit.from_subscription(subscription_id)

    class TerminateForm(FormPage):
        tt_number: TTNumber

    yield TerminateForm
    return {"subscription": layer_2_circuit}


@workflow(
    "Terminate Layer 2 Circuit Service",
    initial_input_form=wrap_modify_initial_input_form(_input_form_generator),
    target=Target.TERMINATE,
)
def terminate_layer_2_circuit() -> StepList:
    """Terminate a Layer 2 Circuit subscription."""
    return (
        begin
        >> store_process_subscription(Target.TERMINATE)
        >> unsync
        >> set_status(SubscriptionLifecycle.TERMINATED)
        >> resync
        >> done
    )
